.. -*- mode: rst -*-

Notes
=====

This is a list to keep track of remaining issues observed via eye-ball
testing for various files.


misc
----

The remaining issues here are mostly related to gradient fillings.

- Python_logo_and_wordmark.svg


wikipedia/flags
---------------

The remaining issues are all related to gradient fillings.

- Belize.svg
- Ecuador.svg
- Guatemala.svg
- Mexico.svg
- Nicaragua.svg


wikipedia/symbols
-----------------

Issues here are often very small and related to text. (The map examples
should perhaps go into a seperate folder.)

- CO2_responsibility_1950-2000.svg (text)
